@@ -1,4 +1,4 @@
-package com.db4odoc.f1.evaluations;
+package com.db4odoc.f1.diagnostics;
 
 import com.db4o.*;
 import com.db4o.config.*;
