@@ -1,6 +1,6 @@
 /* Copyright (C) 2007 db4objects Inc. http://www.db4o.com */
 
-package com.db4odoc.listoperations;
+package com.db4odoc.listdeleting;
 
 
 public class DataObject {
