@@ -1,45 +1,40 @@
 /* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
-namespace Db4objects.Db4odoc.NoClasses.Client
+using System;
+
+namespace Db4objects.Db4odoc.Concurrency
 {
     public class Pilot
     {
-        private string _name;
+        private String _name;
         private int _points;
 
-        public Pilot(string name, int points)
+        public Pilot(String name, int points)
         {
-            _name = name;
-            _points = points;
+            this._name = name;
+            this._points = points;
         }
 
-        public int Points
-        {
-            get
-            {
-                return _points;
-            }
-            set
-            {
-                _points = value;
-            }
-        }
-
-        public void AddPoints(int points)
-        {
-            _points += points;
-        }
-
-        public string Name
+        public String Name
         {
             get
             {
                 return _name;
             }
+            set
+            {
+                _name = value;
+            }
+        }
+
+        public void AddPoints(int points)
+        {
+            this._points += points;
         }
 
         public override string ToString()
         {
-            return string.Format("{0}/{1}", _name, _points);
+            return string.Format("{0}/{1}",_name, _points);
         }
     }
-}
\ No newline at end of file
+
+}
