@@ -2,12 +2,12 @@
 
 using System;
 
-namespace Db4objects.Db4odoc.Activating
+namespace Db4objects.Db4odoc.Utility
 {
 	public class SensorPanel
 	{
-		public Object _sensor;
-		public SensorPanel _next;
+		private Object _sensor;
+		private SensorPanel _next;
 	
 		public SensorPanel()
 		{
@@ -49,6 +49,19 @@ namespace Db4objects.Db4odoc.Activating
 				_next = value;
 			}
 		}
+
+		public Object Sensor
+		{
+			get
+			{
+				return _sensor;
+			}
+            
+			set
+			{
+				_sensor = value;
+			}
+		}
 	
 		protected SensorPanel NewElement(int value)
 		{
