@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com
+/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
 
 This file is part of the db4o open source object database.
 
@@ -29,8 +29,8 @@ namespace Db4objects.Db4o.Tests.Common.Staging
 
 		protected override System.Type[] TestCases()
 		{
-			return new System.Type[] { typeof(Db4objects.Db4o.Tests.Common.Staging.LazyQueryDeleteTestCase)
-				 };
+			return new System.Type[] { typeof(Db4objects.Db4o.Tests.Common.Staging.ObjectVersionTest)
+				, typeof(Db4objects.Db4o.Tests.Common.Staging.LazyQueryDeleteTestCase) };
 		}
 	}
 }
