@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com
+/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
 
 This file is part of the db4o open source object database.
 
@@ -729,8 +729,7 @@ namespace Db4objects.Db4o.Internal.CS
 				for (int i = 0; i < count; i++)
 				{
 					Db4objects.Db4o.Internal.CS.Messages.MsgObject mso = (Db4objects.Db4o.Internal.CS.Messages.MsgObject
-						)Db4objects.Db4o.Internal.CS.Messages.Msg.OBJECT_TO_CLIENT.Clone(GetTransaction(
-						));
+						)Db4objects.Db4o.Internal.CS.Messages.Msg.OBJECT_TO_CLIENT.Clone(a_ta);
 					mso.PayLoad(message.PayLoad().ReadYapBytes());
 					if (mso.PayLoad() != null)
 					{
@@ -1114,5 +1113,15 @@ namespace Db4objects.Db4o.Internal.CS
 		{
 			return i_socket is Db4objects.Db4o.Foundation.Network.LoopbackSocket;
 		}
+
+		public override int ClassMetadataIdForName(string name)
+		{
+			Db4objects.Db4o.Internal.CS.Messages.MsgD msg = Db4objects.Db4o.Internal.CS.Messages.Msg
+				.CLASS_METADATA_ID_FOR_NAME.GetWriterForString(SystemTransaction(), name);
+			msg.Write(this, i_socket);
+			Db4objects.Db4o.Internal.CS.Messages.MsgD response = (Db4objects.Db4o.Internal.CS.Messages.MsgD
+				)ExpectedResponse(Db4objects.Db4o.Internal.CS.Messages.Msg.CLASS_ID);
+			return response.ReadInt();
+		}
 	}
 }
