@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com
+/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
 
 This file is part of the db4o open source object database.
 
@@ -213,6 +213,7 @@ namespace Db4objects.Db4o.Internal
 				}
 			}
 			SetStateOK();
+			ocb.Callbacks().ClassOnRegistered(this);
 		}
 
 		private bool CollectReflectFields(Db4objects.Db4o.Internal.ObjectContainerBase stream
@@ -768,7 +769,7 @@ namespace Db4objects.Db4o.Internal
 			return _eventDispatcher.Dispatch(stream, obj, message);
 		}
 
-		public bool Equals(Db4objects.Db4o.Internal.ITypeHandler4 a_dataType)
+		public bool IsEqual(Db4objects.Db4o.Internal.ITypeHandler4 a_dataType)
 		{
 			return (this == a_dataType);
 		}
@@ -1147,13 +1148,13 @@ namespace Db4objects.Db4o.Internal
 		{
 			Db4objects.Db4o.Internal.FieldMetadata[] yf = new Db4objects.Db4o.Internal.FieldMetadata
 				[1];
-			ForEachYapField(new _AnonymousInnerClass934(this, name, yf));
+			ForEachYapField(new _AnonymousInnerClass935(this, name, yf));
 			return yf[0];
 		}
 
-		private sealed class _AnonymousInnerClass934 : Db4objects.Db4o.Foundation.IVisitor4
+		private sealed class _AnonymousInnerClass935 : Db4objects.Db4o.Foundation.IVisitor4
 		{
-			public _AnonymousInnerClass934(ClassMetadata _enclosing, string name, Db4objects.Db4o.Internal.FieldMetadata[]
+			public _AnonymousInnerClass935(ClassMetadata _enclosing, string name, Db4objects.Db4o.Internal.FieldMetadata[]
 				 yf)
 			{
 				this._enclosing = _enclosing;
@@ -1467,14 +1468,14 @@ namespace Db4objects.Db4o.Internal
 			 yapObject, object obj, Db4objects.Db4o.Internal.Marshall.MarshallerFamily mf, Db4objects.Db4o.Internal.Marshall.ObjectHeaderAttributes
 			 attributes, Db4objects.Db4o.Internal.StatefulBuffer buffer)
 		{
-			obj = InstantiateObject(buffer, mf);
-			if (obj == null)
+			object instantiated = InstantiateObject(buffer, mf);
+			if (instantiated == null)
 			{
 				return null;
 			}
-			buffer.GetStream().Peeked(yapObject.GetID(), obj);
-			InstantiateFields(yapObject, obj, mf, attributes, buffer);
-			return obj;
+			buffer.GetStream().Peeked(yapObject.GetID(), instantiated);
+			InstantiateFields(yapObject, instantiated, mf, attributes, buffer);
+			return instantiated;
 		}
 
 		internal virtual void InstantiateFields(Db4objects.Db4o.Internal.ObjectReference 
@@ -1748,15 +1749,15 @@ namespace Db4objects.Db4o.Internal
 				if (obj != null)
 				{
 					a_candidates.i_trans.Stream().Activate1(trans, obj, 2);
-					Db4objects.Db4o.Internal.Platform4.ForEachCollectionElement(obj, new _AnonymousInnerClass1419
+					Db4objects.Db4o.Internal.Platform4.ForEachCollectionElement(obj, new _AnonymousInnerClass1420
 						(this, a_candidates, trans));
 				}
 			}
 		}
 
-		private sealed class _AnonymousInnerClass1419 : Db4objects.Db4o.Foundation.IVisitor4
+		private sealed class _AnonymousInnerClass1420 : Db4objects.Db4o.Foundation.IVisitor4
 		{
-			public _AnonymousInnerClass1419(ClassMetadata _enclosing, Db4objects.Db4o.Internal.Query.Processor.QCandidates
+			public _AnonymousInnerClass1420(ClassMetadata _enclosing, Db4objects.Db4o.Internal.Query.Processor.QCandidates
 				 a_candidates, Db4objects.Db4o.Internal.Transaction trans)
 			{
 				this._enclosing = _enclosing;
@@ -2144,7 +2145,7 @@ namespace Db4objects.Db4o.Internal
 			stream.Activate1(trans, sc, 4);
 			Db4objects.Db4o.StaticField[] existingFields = sc.fields;
 			System.Collections.IEnumerator staticFields = Db4objects.Db4o.Foundation.Iterators
-				.Map(StaticReflectFields(), new _AnonymousInnerClass1745(this, existingFields, trans
+				.Map(StaticReflectFields(), new _AnonymousInnerClass1746(this, existingFields, trans
 				));
 			sc.fields = ToStaticFieldArray(staticFields);
 			if (!stream.IsClient())
@@ -2153,9 +2154,9 @@ namespace Db4objects.Db4o.Internal
 			}
 		}
 
-		private sealed class _AnonymousInnerClass1745 : Db4objects.Db4o.Foundation.IFunction4
+		private sealed class _AnonymousInnerClass1746 : Db4objects.Db4o.Foundation.IFunction4
 		{
-			public _AnonymousInnerClass1745(ClassMetadata _enclosing, Db4objects.Db4o.StaticField[]
+			public _AnonymousInnerClass1746(ClassMetadata _enclosing, Db4objects.Db4o.StaticField[]
 				 existingFields, Db4objects.Db4o.Internal.Transaction trans)
 			{
 				this._enclosing = _enclosing;
@@ -2197,13 +2198,13 @@ namespace Db4objects.Db4o.Internal
 
 		private System.Collections.IEnumerator StaticReflectFieldsToStaticFields()
 		{
-			return Db4objects.Db4o.Foundation.Iterators.Map(StaticReflectFields(), new _AnonymousInnerClass1773
+			return Db4objects.Db4o.Foundation.Iterators.Map(StaticReflectFields(), new _AnonymousInnerClass1774
 				(this));
 		}
 
-		private sealed class _AnonymousInnerClass1773 : Db4objects.Db4o.Foundation.IFunction4
+		private sealed class _AnonymousInnerClass1774 : Db4objects.Db4o.Foundation.IFunction4
 		{
-			public _AnonymousInnerClass1773(ClassMetadata _enclosing)
+			public _AnonymousInnerClass1774(ClassMetadata _enclosing)
 			{
 				this._enclosing = _enclosing;
 			}
@@ -2251,13 +2252,13 @@ namespace Db4objects.Db4o.Internal
 
 		private System.Collections.IEnumerator StaticReflectFields()
 		{
-			return Db4objects.Db4o.Foundation.Iterators.Filter(ReflectFields(), new _AnonymousInnerClass1803
+			return Db4objects.Db4o.Foundation.Iterators.Filter(ReflectFields(), new _AnonymousInnerClass1804
 				(this));
 		}
 
-		private sealed class _AnonymousInnerClass1803 : Db4objects.Db4o.Foundation.IPredicate4
+		private sealed class _AnonymousInnerClass1804 : Db4objects.Db4o.Foundation.IPredicate4
 		{
-			public _AnonymousInnerClass1803(ClassMetadata _enclosing)
+			public _AnonymousInnerClass1804(ClassMetadata _enclosing)
 			{
 				this._enclosing = _enclosing;
 			}
