@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com
+/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
 
 This file is part of the db4o open source object database.
 
@@ -320,26 +320,50 @@ namespace Db4objects.Db4o.Internal
 				), null);
 		}
 
+		public int ClassMetadataIdForName(string name)
+		{
+			Db4objects.Db4o.Internal.ClassMetadata classMetadata = (Db4objects.Db4o.Internal.ClassMetadata
+				)i_yapClassByBytes.Get(GetNameBytes(name));
+			if (classMetadata == null)
+			{
+				classMetadata = FindInitializedClassByName(name);
+			}
+			if (classMetadata != null)
+			{
+				return classMetadata.GetID();
+			}
+			return 0;
+		}
+
 		public Db4objects.Db4o.Internal.ClassMetadata GetYapClass(string a_name)
 		{
-			Db4objects.Db4o.Internal.ClassMetadata yapClass = (Db4objects.Db4o.Internal.ClassMetadata
+			Db4objects.Db4o.Internal.ClassMetadata classMetadata = (Db4objects.Db4o.Internal.ClassMetadata
 				)i_yapClassByBytes.Remove(GetNameBytes(a_name));
-			ReadYapClass(yapClass, null);
-			if (yapClass == null)
+			if (classMetadata == null)
 			{
-				Db4objects.Db4o.Internal.ClassMetadataIterator i = Iterator();
-				while (i.MoveNext())
-				{
-					yapClass = (Db4objects.Db4o.Internal.ClassMetadata)i.Current;
-					if (a_name.Equals(yapClass.GetName()))
-					{
-						ReadYapClass(yapClass, null);
-						return yapClass;
-					}
-				}
-				return null;
+				classMetadata = FindInitializedClassByName(a_name);
 			}
-			return yapClass;
+			if (classMetadata != null)
+			{
+				ReadYapClass(classMetadata, null);
+			}
+			return classMetadata;
+		}
+
+		private Db4objects.Db4o.Internal.ClassMetadata FindInitializedClassByName(string 
+			name)
+		{
+			Db4objects.Db4o.Internal.ClassMetadataIterator i = Iterator();
+			while (i.MoveNext())
+			{
+				Db4objects.Db4o.Internal.ClassMetadata classMetadata = (Db4objects.Db4o.Internal.ClassMetadata
+					)i.Current;
+				if (name.Equals(classMetadata.GetName()))
+				{
+					return classMetadata;
+				}
+			}
+			return null;
 		}
 
 		public int GetYapClassID(string name)
@@ -484,12 +508,12 @@ namespace Db4objects.Db4o.Internal
 		private void ApplyReadAs()
 		{
 			Db4objects.Db4o.Foundation.Hashtable4 readAs = Stream().ConfigImpl().ReadAs();
-			readAs.ForEachKey(new _AnonymousInnerClass386(this, readAs));
+			readAs.ForEachKey(new _AnonymousInnerClass403(this, readAs));
 		}
 
-		private sealed class _AnonymousInnerClass386 : Db4objects.Db4o.Foundation.IVisitor4
+		private sealed class _AnonymousInnerClass403 : Db4objects.Db4o.Foundation.IVisitor4
 		{
-			public _AnonymousInnerClass386(ClassMetadataRepository _enclosing, Db4objects.Db4o.Foundation.Hashtable4
+			public _AnonymousInnerClass403(ClassMetadataRepository _enclosing, Db4objects.Db4o.Foundation.Hashtable4
 				 readAs)
 			{
 				this._enclosing = _enclosing;
