@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com
+/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
 
 This file is part of the db4o open source object database.
 
@@ -23,7 +23,7 @@ namespace Db4objects.Db4o.Internal
 	/// <exclude></exclude>
 	public class FieldMetadata : Db4objects.Db4o.Ext.IStoredField
 	{
-		private Db4objects.Db4o.Internal.ClassMetadata i_yapClass;
+		private Db4objects.Db4o.Internal.ClassMetadata _clazz;
 
 		private int i_arrayPosition;
 
@@ -60,7 +60,7 @@ namespace Db4objects.Db4o.Internal
 
 		public FieldMetadata(Db4objects.Db4o.Internal.ClassMetadata a_yapClass)
 		{
-			i_yapClass = a_yapClass;
+			_clazz = a_yapClass;
 		}
 
 		internal FieldMetadata(Db4objects.Db4o.Internal.ClassMetadata a_yapClass, Db4objects.Db4o.Config.IObjectTranslator
@@ -390,7 +390,7 @@ namespace Db4objects.Db4o.Internal
 			}
 			try
 			{
-				bool isEnumClass = i_yapClass.IsEnum();
+				bool isEnumClass = _clazz.IsEnum();
 				if (i_isPrimitive && !i_isArray)
 				{
 					if (!isEnumClass)
@@ -478,7 +478,7 @@ namespace Db4objects.Db4o.Internal
 					)obj;
 				yapField.Alive();
 				Alive();
-				return yapField.i_isPrimitive == i_isPrimitive && yapField.i_handler.Equals(i_handler
+				return yapField.i_isPrimitive == i_isPrimitive && yapField.i_handler.IsEqual(i_handler
 					) && yapField.i_name.Equals(i_name);
 			}
 			return false;
@@ -491,9 +491,9 @@ namespace Db4objects.Db4o.Internal
 
 		public virtual object Get(object a_onObject)
 		{
-			if (i_yapClass != null)
+			if (_clazz != null)
 			{
-				Db4objects.Db4o.Internal.ObjectContainerBase stream = i_yapClass.GetStream();
+				Db4objects.Db4o.Internal.ObjectContainerBase stream = _clazz.GetStream();
 				if (stream != null)
 				{
 					lock (stream.i_lock)
@@ -511,9 +511,8 @@ namespace Db4objects.Db4o.Internal
 								{
 									writer._offset = 0;
 									Db4objects.Db4o.Internal.Marshall.ObjectHeader oh = new Db4objects.Db4o.Internal.Marshall.ObjectHeader
-										(stream, i_yapClass, writer);
-									if (oh.ObjectMarshaller().FindOffset(i_yapClass, oh._headerAttributes, writer, this
-										))
+										(stream, _clazz, writer);
+									if (oh.ObjectMarshaller().FindOffset(_clazz, oh._headerAttributes, writer, this))
 									{
 										try
 										{
@@ -600,7 +599,7 @@ namespace Db4objects.Db4o.Internal
 
 		public virtual Db4objects.Db4o.Internal.ClassMetadata GetParentYapClass()
 		{
-			return i_yapClass;
+			return _clazz;
 		}
 
 		public virtual Db4objects.Db4o.Reflect.IReflectClass GetStoredType()
@@ -614,11 +613,11 @@ namespace Db4objects.Db4o.Internal
 
 		public virtual Db4objects.Db4o.Internal.ObjectContainerBase GetStream()
 		{
-			if (i_yapClass == null)
+			if (_clazz == null)
 			{
 				return null;
 			}
-			return i_yapClass.GetStream();
+			return _clazz.GetStream();
 		}
 
 		public virtual bool HasConfig()
@@ -639,7 +638,7 @@ namespace Db4objects.Db4o.Internal
 		public void Init(Db4objects.Db4o.Internal.ClassMetadata a_yapClass, string a_name
 			)
 		{
-			i_yapClass = a_yapClass;
+			_clazz = a_yapClass;
 			i_name = a_name;
 			InitIndex(a_yapClass, a_name);
 		}
@@ -737,7 +736,7 @@ namespace Db4objects.Db4o.Internal
 		private void LoadJavaField()
 		{
 			Db4objects.Db4o.Internal.ITypeHandler4 handler = LoadJavaField1();
-			if (handler == null || (!handler.Equals(i_handler)))
+			if (handler == null || (!handler.IsEqual(i_handler)))
 			{
 				i_javaField = null;
 				i_state = UNAVAILABLE;
@@ -748,7 +747,7 @@ namespace Db4objects.Db4o.Internal
 		{
 			try
 			{
-				Db4objects.Db4o.Reflect.IReflectClass claxx = i_yapClass.ClassReflector();
+				Db4objects.Db4o.Reflect.IReflectClass claxx = _clazz.ClassReflector();
 				if (claxx == null)
 				{
 					return null;
@@ -759,7 +758,7 @@ namespace Db4objects.Db4o.Internal
 					return null;
 				}
 				i_javaField.SetAccessible();
-				Db4objects.Db4o.Internal.ObjectContainerBase stream = i_yapClass.GetStream();
+				Db4objects.Db4o.Internal.ObjectContainerBase stream = _clazz.GetStream();
 				stream.ShowInternalClasses(true);
 				try
 				{
@@ -785,10 +784,9 @@ namespace Db4objects.Db4o.Internal
 				|| (i_config != null && (i_config.CascadeOnUpdate().DefiniteYes()))))
 			{
 				int min = 1;
-				if (i_yapClass.IsCollection(obj))
+				if (_clazz.IsCollection(obj))
 				{
-					Db4objects.Db4o.Reflect.Generic.GenericReflector reflector = i_yapClass.Reflector
-						();
+					Db4objects.Db4o.Reflect.Generic.GenericReflector reflector = _clazz.Reflector();
 					min = reflector.CollectionUpdateDepth(reflector.ForObject(obj));
 				}
 				int updateDepth = writer.GetUpdateDepth();
@@ -831,9 +829,9 @@ namespace Db4objects.Db4o.Internal
 			 a_trans)
 		{
 			int yapClassID = 0;
-			if (i_yapClass != null)
+			if (_clazz != null)
 			{
-				yapClassID = i_yapClass.GetID();
+				yapClassID = _clazz.GetID();
 			}
 			return new Db4objects.Db4o.Internal.Query.Processor.QField(a_trans, i_name, this, 
 				yapClassID, i_arrayPosition);
@@ -869,7 +867,7 @@ namespace Db4objects.Db4o.Internal
 			if (handler != null)
 			{
 				handler = WrapHandlerToArrays(GetStream(), handler);
-				if (handler.Equals(i_handler))
+				if (handler.IsEqual(i_handler))
 				{
 					return;
 				}
@@ -880,12 +878,12 @@ namespace Db4objects.Db4o.Internal
 
 		public virtual void Rename(string newName)
 		{
-			Db4objects.Db4o.Internal.ObjectContainerBase stream = i_yapClass.GetStream();
+			Db4objects.Db4o.Internal.ObjectContainerBase stream = _clazz.GetStream();
 			if (!stream.IsClient())
 			{
 				i_name = newName;
-				i_yapClass.SetStateDirty();
-				i_yapClass.Write(stream.GetSystemTransaction());
+				_clazz.SetStateDirty();
+				_clazz.Write(stream.GetSystemTransaction());
 			}
 			else
 			{
@@ -926,7 +924,7 @@ namespace Db4objects.Db4o.Internal
 				return;
 			}
 			AssertHasIndex();
-			Db4objects.Db4o.Internal.ObjectContainerBase stream = i_yapClass.GetStream();
+			Db4objects.Db4o.Internal.ObjectContainerBase stream = _clazz.GetStream();
 			if (stream.IsClient())
 			{
 				Db4objects.Db4o.Internal.Exceptions4.ThrowRuntimeException(Db4objects.Db4o.Internal.Messages
@@ -995,9 +993,9 @@ namespace Db4objects.Db4o.Internal
 		public override string ToString()
 		{
 			System.Text.StringBuilder sb = new System.Text.StringBuilder();
-			if (i_yapClass != null)
+			if (_clazz != null)
 			{
-				sb.Append(i_yapClass.GetName());
+				sb.Append(_clazz.GetName());
 				sb.Append(".");
 				sb.Append(GetName());
 			}
@@ -1184,5 +1182,31 @@ namespace Db4objects.Db4o.Internal
 		{
 			GetHandler().Defrag(mf, readers, true);
 		}
+
+		public virtual void CreateIndex()
+		{
+			if (HasIndex())
+			{
+				return;
+			}
+			Db4objects.Db4o.Internal.LocalObjectContainer container = (Db4objects.Db4o.Internal.LocalObjectContainer
+				)_clazz.GetStream();
+			if (container.ConfigImpl().MessageLevel() > Db4objects.Db4o.Internal.Const4.NONE)
+			{
+				container.Message("creating index " + ToString());
+			}
+			InitIndex(container.GetSystemTransaction());
+			container.SetDirtyInSystemTransaction(GetParentYapClass());
+			Reindex(container);
+		}
+
+		private void Reindex(Db4objects.Db4o.Internal.LocalObjectContainer container)
+		{
+			Db4objects.Db4o.Internal.ClassMetadata clazz = GetParentYapClass();
+			if (RebuildIndexForClass(container, clazz))
+			{
+				container.GetSystemTransaction().Commit();
+			}
+		}
 	}
 }
