@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com
+/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
 
 This file is part of the db4o open source object database.
 
@@ -80,6 +80,10 @@ namespace Db4objects.Db4o.Internal
 			return ret;
 		}
 
+		/// <summary>might be overriden by subclass.</summary>
+		/// <remarks>might be overriden by subclass.</remarks>
+		public abstract void ShutdownStorage();
+
 		public override void Commit1()
 		{
 			try
@@ -221,14 +225,14 @@ namespace Db4objects.Db4o.Internal
 		{
 			if (i_prefetchedIDs != null)
 			{
-				i_prefetchedIDs.Traverse(new _AnonymousInnerClass213(this));
+				i_prefetchedIDs.Traverse(new _AnonymousInnerClass222(this));
 			}
 			i_prefetchedIDs = null;
 		}
 
-		private sealed class _AnonymousInnerClass213 : Db4objects.Db4o.Foundation.IVisitor4
+		private sealed class _AnonymousInnerClass222 : Db4objects.Db4o.Foundation.IVisitor4
 		{
-			public _AnonymousInnerClass213(LocalObjectContainer _enclosing)
+			public _AnonymousInnerClass222(LocalObjectContainer _enclosing)
 			{
 				this._enclosing = _enclosing;
 			}
@@ -631,16 +635,16 @@ namespace Db4objects.Db4o.Internal
 				Db4objects.Db4o.Foundation.Hashtable4 semaphores = i_semaphores;
 				lock (semaphores)
 				{
-					semaphores.ForEachKeyForIdentity(new _AnonymousInnerClass591(this, semaphores), ta
+					semaphores.ForEachKeyForIdentity(new _AnonymousInnerClass600(this, semaphores), ta
 						);
 					Sharpen.Runtime.NotifyAll(semaphores);
 				}
 			}
 		}
 
-		private sealed class _AnonymousInnerClass591 : Db4objects.Db4o.Foundation.IVisitor4
+		private sealed class _AnonymousInnerClass600 : Db4objects.Db4o.Foundation.IVisitor4
 		{
-			public _AnonymousInnerClass591(LocalObjectContainer _enclosing, Db4objects.Db4o.Foundation.Hashtable4
+			public _AnonymousInnerClass600(LocalObjectContainer _enclosing, Db4objects.Db4o.Foundation.Hashtable4
 				 semaphores)
 			{
 				this._enclosing = _enclosing;
@@ -894,13 +898,13 @@ namespace Db4objects.Db4o.Internal
 		{
 			Db4objects.Db4o.Foundation.IntArrayList ids = new Db4objects.Db4o.Foundation.IntArrayList
 				();
-			clazz.Index().TraverseAll(trans, new _AnonymousInnerClass806(this, ids));
+			clazz.Index().TraverseAll(trans, new _AnonymousInnerClass815(this, ids));
 			return ids.AsLong();
 		}
 
-		private sealed class _AnonymousInnerClass806 : Db4objects.Db4o.Foundation.IVisitor4
+		private sealed class _AnonymousInnerClass815 : Db4objects.Db4o.Foundation.IVisitor4
 		{
-			public _AnonymousInnerClass806(LocalObjectContainer _enclosing, Db4objects.Db4o.Foundation.IntArrayList
+			public _AnonymousInnerClass815(LocalObjectContainer _enclosing, Db4objects.Db4o.Foundation.IntArrayList
 				 ids)
 			{
 				this._enclosing = _enclosing;
