@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com
+/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
 
 This file is part of the db4o open source object database.
 
@@ -988,6 +988,17 @@ namespace Db4objects.Db4o.Internal
 			return new Db4objects.Db4o.Internal.StatefulBuffer(a_trans, a_address, a_length);
 		}
 
+		public Db4objects.Db4o.Internal.Transaction SystemTransaction()
+		{
+			return i_systemTrans;
+		}
+
+		/// <deprecated>
+		/// use
+		/// <see cref="Db4objects.Db4o.Internal.PartialObjectContainer.SystemTransaction">Db4objects.Db4o.Internal.PartialObjectContainer.SystemTransaction
+		/// 	</see>
+		/// instead
+		/// </deprecated>
 		public Db4objects.Db4o.Internal.Transaction GetSystemTransaction()
 		{
 			return i_systemTrans;
@@ -2198,7 +2209,10 @@ namespace Db4objects.Db4o.Internal
 				Db4objects.Db4o.Internal.Platform4.RemoveShutDownHook(this, i_lock);
 			}
 			_classCollection = null;
-			i_references.StopTimer();
+			if (i_references != null)
+			{
+				i_references.StopTimer();
+			}
 		}
 
 		public virtual Db4objects.Db4o.Ext.IStoredClass StoredClass(object clazz)
@@ -2374,6 +2388,11 @@ namespace Db4objects.Db4o.Internal
 			return _classCollection;
 		}
 
+		public virtual int ClassMetadataIdForName(string name)
+		{
+			return _classCollection.ClassMetadataIdForName(name);
+		}
+
 		public virtual Db4objects.Db4o.Internal.CS.ClassInfoHelper GetClassMetaHelper()
 		{
 			return _classMetaHelper;
