@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com
+/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
 
 This file is part of the db4o open source object database.
 
@@ -271,8 +271,8 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 				public void Visit(object a_object)
 				{
-					Db4objects.Db4o.Internal.Query.Processor.QPending newPending = (Db4objects.Db4o.Internal.Query.Processor.QPending
-						)a_object;
+					Db4objects.Db4o.Internal.Query.Processor.QPending newPending = ((Db4objects.Db4o.Internal.Query.Processor.QPending
+						)a_object).InternalClonePayload();
 					newPending.ChangeConstraint();
 					Db4objects.Db4o.Internal.Query.Processor.QPending oldPending = (Db4objects.Db4o.Internal.Query.Processor.QPending
 						)Db4objects.Db4o.Foundation.Tree.Find(pending.value, newPending);
