@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com
+/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
 
 This file is part of the db4o open source object database.
 
@@ -81,6 +81,11 @@ namespace Db4objects.Db4o.Internal
             return className.StartsWith("Db4objects.Db4o");
         }
 
+        internal static string FullyQualifiedName(System.Type type)
+        {
+            return Sharpen.Lang.TypeReference.FromType(type).GetUnversionedName();
+        }
+
         internal static JDK Jdk()
         {
             throw new NotSupportedException();
